==> qtjambi-activex-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiActiveX/QAxObject_shell.h <==
#ifndef QAXOBJECT_SHELL_H
#define QAXOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxObject_shell : public QAxObject, public QtJambiShellInterface
{
public:
    QAxObject_shell(QObject* parent0 = nullptr);
    QAxObject_shell(const QString& c0, QObject* parent1 = nullptr);
    ~QAxObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    const char* className() const override;
    void clear() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    const QMetaObject* fallbackMetaObject() const override;
    bool propertyWritable(const char* arg__1) const override;
    QObject* qObject() const override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__className_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxObject_access : public QAxObject
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_className(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
    jobject __qt_fallbackMetaObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    jobject __qt_qObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
};

#endif // defined(Q_OS_WIN)
#endif // QAXOBJECT_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiActiveX/QAxObject_shell.h <==
#ifndef QAXOBJECT_SHELL_H
#define QAXOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxObject_shell : public QAxObject, public QtJambiShellInterface
{
public:
    QAxObject_shell(QObject* parent0 = nullptr);
    QAxObject_shell(const QString& c0, QObject* parent1 = nullptr);
    ~QAxObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    const char* className() const override;
    void clear() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    const QMetaObject* fallbackMetaObject() const override;
    bool propertyWritable(const char* arg__1) const override;
    QObject* qObject() const override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__className_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxObject_access : public QAxObject
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_className_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
    jobject __qt_fallbackMetaObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    jobject __qt_qObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
};

#endif // defined(Q_OS_WIN)
#endif // QAXOBJECT_SHELL_H
